@@ -93,6 +93,9 @@ def marker_options(func):
     func = click.option(
         "--page_schema", help="Schema to set to do structured extraction"
     )(func)
+    func = click.option(
+        "--add_block_ids", is_flag=True, help="Add block IDs to HTML output"
+    )(func)
     return func
 
 
@@ -139,13 +142,19 @@ async def process_files_async(
                 ) as client:
                     if method == "convert":
                         result = await client.convert(
-                            file_path, options=options, save_output=output_path,
-                            max_polls=max_polls, poll_interval=poll_interval
+                            file_path,
+                            options=options,
+                            save_output=output_path,
+                            max_polls=max_polls,
+                            poll_interval=poll_interval,
                         )
                     else:  # method == 'ocr'
                         result = await client.ocr(
-                            file_path, options=options, save_output=output_path,
-                            max_polls=max_polls, poll_interval=poll_interval
+                            file_path,
+                            options=options,
+                            save_output=output_path,
+                            max_polls=max_polls,
+                            poll_interval=poll_interval,
                         )
 
                 return {
@@ -197,7 +206,7 @@ def get_files_to_process(
     if path.is_file():
         # Single file processing
         if file_extensions and path.suffix.lower() not in file_extensions:
-            click.echo(f"❌ Skipping {path}: unsupported file type", err=True)
+            click.echo(f"Skipping {path}: unsupported file type", err=True)
             sys.exit(1)
         return [path]
     else:
@@ -210,10 +219,10 @@ def show_results(results: List[dict], operation: str, output_dir: Path):
     successful = sum(1 for r in results if r["success"])
     failed = len(results) - successful
 
-    click.echo(f"\n📊 {operation} Summary:")
-    click.echo(f"   ✅ Successfully processed: {successful} files")
+    click.echo(f"\n{operation} Summary:")
+    click.echo(f"   Successfully processed: {successful} files")
     if failed > 0:
-        click.echo(f"   ❌ Failed: {failed} files")
+        click.echo(f"   Failed: {failed} files")
 
         # Show failed files
         click.echo("\n   Failed files:")
@@ -221,7 +230,7 @@ def show_results(results: List[dict], operation: str, output_dir: Path):
             if not result["success"]:
                 click.echo(f"      - {result['file_path']}: {result['error']}")
 
-    click.echo(f"\n📁 Output saved to: {output_dir}")
+    click.echo(f"\nOutput saved to: {output_dir}")
 
 
 def process_documents(
@@ -247,6 +256,7 @@ def process_documents(
     disable_image_extraction: bool = False,
     block_correction_prompt: Optional[str] = None,
     page_schema: Optional[str] = None,
+    add_block_ids: bool = False,
 ):
     """Unified document processing function"""
     try:
@@ -270,10 +280,10 @@ def process_documents(
         to_process = get_files_to_process(path, file_extensions)
 
         if not to_process:
-            click.echo(f"❌ No supported files found in {path}", err=True)
+            click.echo(f"No supported files found in {path}", err=True)
             sys.exit(1)
 
-        click.echo(f"📂 Found {len(to_process)} files to process")
+        click.echo(f"Found {len(to_process)} files to process")
 
         # Create processing options based on method
         if method == "convert":
@@ -290,6 +300,7 @@ def process_documents(
                 block_correction_prompt=block_correction_prompt,
                 skip_cache=skip_cache,
                 page_schema=page_schema,
+                add_block_ids=add_block_ids,
             )
         else:  # method == "ocr"
             options = OCROptions(
@@ -317,7 +328,7 @@ def process_documents(
         show_results(results, operation, output_dir)
 
     except DatalabError as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
 
 
@@ -352,6 +363,7 @@ def convert(
     disable_image_extraction: bool,
     block_correction_prompt: Optional[str],
     page_schema: Optional[str],
+    add_block_ids: bool,
 ):
     """Convert documents to markdown, HTML, or JSON"""
     process_documents(
@@ -376,6 +388,7 @@ def convert(
         disable_image_extraction=disable_image_extraction,
         block_correction_prompt=block_correction_prompt,
         page_schema=page_schema,
+        add_block_ids=add_block_ids,
     )
 
 
@@ -465,17 +478,17 @@ def create_workflow(
             name=name, team_id=team_id, steps=workflow_steps
         )
 
-        click.echo(f"✅ Workflow created successfully!")
+        click.echo("Workflow created successfully!")
         click.echo(f"   ID: {workflow.id}")
         click.echo(f"   Name: {workflow.name}")
         click.echo(f"   Team ID: {workflow.team_id}")
         click.echo(f"   Steps: {len(workflow.steps)}")
 
     except DatalabError as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
     except Exception as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
 
 
@@ -497,7 +510,7 @@ def get_workflow(workflow_id: int, api_key: Optional[str], base_url: str):
         client = DatalabClient(api_key=api_key, base_url=base_url)
         workflow = client.get_workflow(workflow_id)
 
-        click.echo(f"📋 Workflow Details:")
+        click.echo("Workflow Details:")
         click.echo(f"   ID: {workflow.id}")
         click.echo(f"   Name: {workflow.name}")
         click.echo(f"   Team ID: {workflow.team_id}")
@@ -512,7 +525,48 @@ def get_workflow(workflow_id: int, api_key: Optional[str], base_url: str):
                 click.echo(f"      Depends on: {', '.join(step.depends_on)}")
 
     except DatalabError as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
+        sys.exit(1)
+
+
+@click.command()
+@click.option("--api_key", required=False, help="Datalab API key")
+@click.option("--base_url", default=settings.DATALAB_HOST, help="API base URL")
+def get_step_types(api_key: Optional[str], base_url: str):
+    """Get all available workflow step types"""
+    try:
+        if api_key is None:
+            api_key = settings.DATALAB_API_KEY
+
+        if api_key is None:
+            raise DatalabError(
+                "You must either pass in an api key via --api_key or set the DATALAB_API_KEY env variable."
+            )
+
+        client = DatalabClient(api_key=api_key, base_url=base_url)
+        response = client.get_step_types()
+
+        step_types = response.get("step_types", [])
+        if not step_types:
+            click.echo("No step types found.")
+            return
+
+        click.echo(f"Found {len(step_types)} step type(s):\n")
+        for step_type in step_types:
+            click.echo("━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━")
+            click.echo(f"Key:         {step_type.get('type')}")
+            click.echo(f"Version:     {step_type.get('version')}")
+            click.echo(f"Name:        {step_type.get('name')}")
+            if step_type.get("description"):
+                click.echo(f"Description: {step_type['description']}")
+
+            if step_type.get("settings_schema"):
+                click.echo("\nSettings Schema:")
+                click.echo(json.dumps(step_type["settings_schema"], indent=2))
+            click.echo("")
+
+    except DatalabError as e:
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
 
 
@@ -537,7 +591,7 @@ def list_workflows(api_key: Optional[str], base_url: str):
             click.echo("No workflows found.")
             return
 
-        click.echo(f"📋 Found {len(workflows)} workflow(s):\n")
+        click.echo(f"Found {len(workflows)} workflow(s):\n")
         for workflow in workflows:
             click.echo(f"   ID: {workflow.id}")
             click.echo(f"   Name: {workflow.name}")
@@ -547,7 +601,7 @@ def list_workflows(api_key: Optional[str], base_url: str):
             click.echo("")
 
     except DatalabError as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
 
 
@@ -595,25 +649,27 @@ def execute_workflow(
 
         client = DatalabClient(api_key=api_key, base_url=base_url)
 
-        click.echo(f"🚀 Triggering workflow execution for workflow {workflow_id}...")
+        click.echo(f"Triggering workflow execution for workflow {workflow_id}...")
         execution = client.execute_workflow(
             workflow_id=workflow_id,
             input_config=input_cfg,
         )
 
-        click.echo(f"\n✅ Successfully triggered workflow execution!")
+        click.echo("\nSuccessfully triggered workflow execution!")
         click.echo(f"   Execution ID: {execution.id}")
         click.echo(f"   Status: {execution.status}")
-        click.echo(f"\n💡 To check the status, run:")
+        click.echo("\nTo check the status, run:")
         click.echo(f"   datalab get-execution-status --execution_id {execution.id}")
-        click.echo(f"\n   Or poll until complete:")
-        click.echo(f"   datalab get-execution-status --execution_id {execution.id} --max_polls 300 --poll_interval 2")
+        click.echo("\n   Or poll until complete:")
+        click.echo(
+            f"   datalab get-execution-status --execution_id {execution.id} --max_polls 300 --poll_interval 2"
+        )
 
     except DatalabError as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
     except Exception as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
 
 
@@ -626,13 +682,18 @@ def execute_workflow(
     help="Output file path to save execution results",
 )
 @click.option(
-    "--max_polls", default=1, type=int, help="Maximum number of polling attempts (1 for single check)"
+    "--max_polls",
+    default=1,
+    type=int,
+    help="Maximum number of polling attempts (1 for single check)",
+)
+@click.option(
+    "--poll_interval", default=1, type=int, help="Polling interval in seconds"
 )
-@click.option("--poll_interval", default=1, type=int, help="Polling interval in seconds")
 @click.option(
     "--download",
     is_flag=True,
-    help="Download actual results from presigned URLs (default: just show URLs)"
+    help="Download actual results from presigned URLs (default: just show URLs)",
 )
 @click.option("--api_key", required=False, help="Datalab API key")
 @click.option("--base_url", default=settings.DATALAB_HOST, help="API base URL")
@@ -663,46 +724,69 @@ def get_execution_status(
             download_results=download,
         )
 
-        click.echo(f"📊 Execution Status:")
+        click.echo("Execution Status:")
         click.echo(f"   Execution ID: {execution.id}")
         click.echo(f"   Workflow ID: {execution.workflow_id}")
         click.echo(f"   Status: {execution.status}")
         click.echo(f"   Success: {execution.success}")
         click.echo(f"   Created: {execution.created}")
-        if execution.completed:
-            click.echo(f"   Completed: {execution.completed}")
 
-        if execution.error:
-            click.echo(f"   Error: {execution.error}")
-
-        if execution.results:
-            click.echo(f"\n   Step Results:")
-            for step_name, step_data in execution.results.items():
+        if execution.steps:
+            click.echo("\n   Step Results:")
+            for step_name, step_data in execution.steps.items():
                 click.echo(f"\n   [{step_name}]")
-                if isinstance(step_data, dict):
-                    if "output_url" in step_data and not download:
-                        click.echo(f"      Status: {step_data.get('status', 'N/A')}")
-                        click.echo(f"      Output URL: {step_data.get('output_url')}")
-                        click.echo(f"      💡 Use --download to fetch actual results")
+
+                # Iterate through file_ids/aggregated keys
+                for file_key, file_step_data in step_data.items():
+                    if isinstance(file_step_data, dict):
+                        click.echo(f"\n      File/Group: {file_key}")
+                        click.echo(
+                            f"         Step ID: {file_step_data.get('id', 'N/A')}"
+                        )
+                        click.echo(
+                            f"         Status: {file_step_data.get('status', 'N/A')}"
+                        )
+
+                        if file_step_data.get("started_at"):
+                            click.echo(
+                                f"         Started: {file_step_data.get('started_at')}"
+                            )
+                        if file_step_data.get("finished_at"):
+                            click.echo(
+                                f"         Finished: {file_step_data.get('finished_at')}"
+                            )
+                        if file_step_data.get("file_ids"):
+                            click.echo(
+                                f"         Files: {', '.join(file_step_data.get('file_ids'))}"
+                            )
+
+                        if "output_url" in file_step_data and not download:
+                            click.echo(
+                                f"         Output URL: {file_step_data.get('output_url')}"
+                            )
+                        elif download and "downloaded_data" in file_step_data:
+                            click.echo(
+                                f"         Results: {json.dumps(file_step_data['downloaded_data'], indent=12)}"
+                            )
                     else:
-                        click.echo(f"      {json.dumps(step_data, indent=8)}")
-                else:
-                    click.echo(f"      {step_data}")
+                        click.echo(f"      {file_step_data}")
 
         # Save output if requested
         if output:
             output_path = Path(output)
             output_path.parent.mkdir(parents=True, exist_ok=True)
             execution.save_output(output_path)
-            click.echo(f"\n📁 Results saved to: {output_path}")
+            click.echo(f"\nResults saved to: {output_path}")
 
     except DatalabError as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
 
 
 @click.command()
-@click.option("--definition", required=True, help="Path to workflow definition JSON file")
+@click.option(
+    "--definition", required=True, help="Path to workflow definition JSON file"
+)
 def visualize_workflow(definition: str):
     """Visualize workflow DAG from a JSON definition file"""
     try:
@@ -715,22 +799,22 @@ def visualize_workflow(definition: str):
         if not definition_path.exists():
             raise DatalabError(f"Definition file not found: {definition}")
 
-        with open(definition_path, 'r') as f:
+        with open(definition_path, "r") as f:
             workflow_def = json.load(f)
 
         name = workflow_def.get("name", "Unnamed Workflow")
         steps = workflow_def.get("steps", [])
 
         if not steps:
-            click.echo("⚠️  No steps found in workflow definition")
+            click.echo("No steps found in workflow definition")
             return
 
         # Build dependency graph
         step_map = {step["unique_name"]: step for step in steps}
 
-        click.echo(f"\n{'='*70}")
+        click.echo(f"\n{'=' * 70}")
         click.echo(f"Workflow: {name}")
-        click.echo(f"{'='*70}\n")
+        click.echo(f"{'=' * 70}\n")
 
         # Build parent/child maps
         children = defaultdict(list)
@@ -740,9 +824,13 @@ def visualize_workflow(definition: str):
                 children[dep].append(step_name)
 
         # Topological sort to determine layers
-        in_degree = {step["unique_name"]: len(step.get("depends_on", [])) for step in steps}
+        in_degree = {
+            step["unique_name"]: len(step.get("depends_on", [])) for step in steps
+        }
         layers = []
-        queue = deque([s["unique_name"] for s in steps if in_degree[s["unique_name"]] == 0])
+        queue = deque(
+            [s["unique_name"] for s in steps if in_degree[s["unique_name"]] == 0]
+        )
 
         while queue:
             layer = []
@@ -761,13 +849,13 @@ def visualize_workflow(definition: str):
         click.echo(f"\nTotal steps: {len(steps)}")
 
     except json.JSONDecodeError as e:
-        click.echo(f"❌ Invalid JSON: {e}", err=True)
+        click.echo(f"Invalid JSON: {e}", err=True)
         sys.exit(1)
     except KeyError as e:
-        click.echo(f"❌ Missing required field in workflow definition: {e}", err=True)
+        click.echo(f"Missing required field in workflow definition: {e}", err=True)
         sys.exit(1)
     except Exception as e:
-        click.echo(f"❌ Error: {e}", err=True)
+        click.echo(f"Error: {e}", err=True)
         sys.exit(1)
 
 
@@ -796,11 +884,17 @@ def _render_dag_simple(layers, children, step_map):
 
             # Show the step - color code by step type
             step_color = "blue" if "marker" in step_key else "magenta"
-            click.echo(f"  • {click.style(step_name, fg=step_color)} ({click.style(step_key, fg='white', dim=True)})")
+            click.echo(
+                f"  • {click.style(step_name, fg=step_color)} ({click.style(step_key, fg='white', dim=True)})"
+            )
 
             # Show dependencies if any
             if depends:
-                click.echo(click.style(f"    ← depends on: {', '.join(depends)}", fg="white", dim=True))
+                click.echo(
+                    click.style(
+                        f"    ← depends on: {', '.join(depends)}", fg="white", dim=True
+                    )
+                )
 
         # Show what comes next
         if layer_idx < len(layers) - 1:
@@ -814,6 +908,7 @@ cli.add_command(convert)
 cli.add_command(ocr)
 cli.add_command(create_workflow)
 cli.add_command(get_workflow)
+cli.add_command(get_step_types)
 cli.add_command(list_workflows)
 cli.add_command(execute_workflow)
 cli.add_command(get_execution_status)
